=======
History
=======

0.0.2 (2016-04-24)
------------------
* First release on PyPI.
* Implementation of metrics/storage/options/stats
* Builds are tested by docker container with Apache Drill running
* support for pandas with ResultQuery.to_dataframe

0.0.1 (2015-12-28)
------------------
* Project start
